@@ -1,8 +1,8 @@
-version = '0.0.2'
+version = '0.1.0'
 __version__ = version
 
 class KeyGenerator:
-    def __init__(self, start=-1):
+    def __init__(self, start=0):
         self.i = start
         
     def next(self):
@@ -11,48 +11,74 @@ class KeyGenerator:
 
 
 class Collection(object):
-    def __init__(self, *suites):
-        self._orderby = 'priority'
-        self._suites = sorted(suites,
-                              key=lambda s: getattr(s, self.orderby))
+    def __init__(self, *suites, **kwargs):
+        self._suites = []
+        self._fitter = kwargs.get('fitter', None)
+        self._key_gen = KeyGenerator()
+        if suites:
+            for suite in self._suites:
+                suite._key_gen = self._key_gen
+            self._suites = sorted(suites)
+            
 
     def push(self, suite):
         assert isinstance(suite, Suite)
         self._suites.append(suite)
-        self._suites = sorted(self._suites,
-                              key=lambda s: getattr(s, self.orderby))
+        self._suites = sorted(self._suites)
 
     def append(self, value):
+        """Checks for best fit suite via sorted suites -> fitter
+        """
+        # try best fit
+        for suite in self._suites:
+            if self._fitter and suite._check_value(value) and self._fitter(self, suite, value):
+                if suite.append(value):
+                    return True
+        # try any fit
         for suite in self._suites:
             if suite.append(value):
                 return True
         return False
 
     @property
-    def orderby(self):
-        return self._orderby
-
-    @orderby.setter
-    def orderby(self, attr):
-        self._orderby = attr
-
-    def __len__(self):
-        return len(self._suites)
-    
-    def __iter__(self):
+    def suites(self):
         return self._suites
 
+    def __len__(self):
+        return sum([len(s) for s in self._suites])
+    
+    def values(self):
+        values = []
+        [[values.append(value) for value in suite] for suite in self._suites]
+        return values
+
+    def keys(self):
+        keys = []
+        [[keys.append(key) for key in suite.keys()] for suite in self._suites]
+        return keys
+
+    def clear(self):
+        [suite.clear() for suite in self._suites]
+
+    def __iter__(self):
+        return iter(self.values())
+
+    def __getitem__(self, key):
+        for suite in self._suites:
+            if suite.has_get(key):
+                return suite.get(key)
 
 
 class Suite( object ):
-    def __init__(self, getter=None, setter=None, changed=None, yielder=None, max=None, priority=0, keygen_start=0):
+    def __init__(self, getter=None, check=None, changed=None, yielder=None, max=None, priority=0):
         self._getter = getter
-        self._setter = setter
+        self._checker = check
         self._changed = changed
         self._yielder = yielder
         self._dict = {}
-        self._key_gen = KeyGenerator(keygen_start)
+        self._key_gen = KeyGenerator()
         self._max = max
+        # default method for sorting
         self._priority = priority
     
     # -------------
@@ -60,17 +86,14 @@ class Suite( object ):
     # -------------
     def _get_next_key(self):
         key = self._key_gen.next()
-        if not self._dict.has_key(key):
+        if key not in self._dict:
             return key
-        while self._dict.has_key(key):
+        while key in self._dict:
             key = self._key_gen.next()
         return key
 
-    def get_all(self):
-        return self._dict
-
     def __getitem__(self, key):
-        if self._dict.has_key(key):
+        if key in self._dict:
             return self._dict.get(key)
         else:
             if self._getter is not None:
@@ -78,15 +101,9 @@ class Suite( object ):
             else:
                 raise KeyError(key)
 
-    def iteritems(self):
-        return self._dict
-
     def keys(self):
         return self._dict.keys()
 
-    def has_key(self, key):
-        return self._dict.has_key(key)
-    
     def values(self):
         return self._dict.values()
 
@@ -118,7 +135,7 @@ class Suite( object ):
         if self._max_hit():
             return False
         key = self._get_next_key()
-        if self._on_append(key, value):
+        if self._check_value(value):
             self._dict[key] = value
             self._on_changed()
             return key
@@ -126,7 +143,7 @@ class Suite( object ):
             return False
 
     def setdefault(self, key, value):
-        if self._dict.has_key(key):
+        if key in self._dict:
             return self._dict[key]
         else:
             return self.put(key, value)
@@ -168,22 +185,13 @@ class Suite( object ):
         return self._yielder() if self._yielder else iter(self._dict.values())
 
     def __lt__(self, other):
-        if isinstance(other, Suite):
-            return len(self) < len(other)
-        else:
-            return len(self) < other
+        return self.priority < other.priority
 
     def __gt__(self, other):
-        if isinstance(other, Suite):
-            return len(self) > len(other)
-        else:
-            return len(self) > other
+        return self.priority > other.priority
 
     def __eq__(self, other):
-        if isinstance(other, Suite):
-            return len(self) == len(other)
-        else:
-            return len(self) == other
+        return self.priority == other.priority
 
     # -------------
     # Properties
@@ -206,7 +214,7 @@ class Suite( object ):
 
     @property
     def setter(self, callback):
-        self._setter = callback
+        self._checker = callback
 
     @property
     def priority(self):
@@ -223,12 +231,12 @@ class Suite( object ):
         if self._changed is not None:
             self._changed(self)
 
-    def _on_append(self, key, value):
-        assert self._setter is not False, "Not allowed to add to this Suite"
-        if self._setter is None:
+    def _check_value(self, value):
+        assert self._checker is not False, "Not allowed to add to this Suite"
+        if self._checker is None:
             return True
         else:
-            return self._setter(key, value) is not False
+            return self._checker(self, value) is not False
 
     def _max_hit(self):
         return self.max is not None and len(self._dict) >= self.max
